library (shiny)

source(paste(getwd(),'global.R',sep="/"))

server <- function(input, output,session){


##### data input
	dataInput <- reactiveValues(
		dataCount = read.delim(paste(getwd(),"/data/public_data/raw_counts.csv",sep="/"), header=T, row.names=1),
		dataMeta = read.delim(paste(getwd(),"/data/public_data/sample_info.txt",sep="/"), header=T) 
    )
	
	myValues <- eventReactive(input$upload, {
	withProgress(message = 'Submit:', value = 0,{
	incProgress(.1, detail = paste("Uploading dataset"))
    if (is.null(input$countFile) & is.null(input$metaTab) ) {
      dataInput$dataCount <- read.delim(paste(getwd(),"/data/public_data/raw_counts.csv",sep="/"), header=T, sep=",", row.names=1)
      dataInput$dataMeta <- read.delim(paste(getwd(),"/data/public_data/sample_info.txt",sep=""), header=T, sep="\t")
    } else if (!is.null(input$countFile) & is.null(input$metaTab) ) {
      dataInput$dataCount <- read.delim(paste(getwd(),"/data/public_data/raw_counts.csv",sep="/"), header=T, sep=",", row.names=1)
      dataInput$dataMeta <- NULL
    } else if (is.null(input$countFile) & !is.null(input$metaTab) ) {
      dataInput$dataCount <- NULL
      dataInput$dataMeta <- read.delim(paste(getwd(),"/data/public_data/sample_info.txt",sep=""), header=T, sep="\t")
    }   
    list(meta=(dataInput$dataMeta), count=(dataInput$dataCount) )
  })})
  
  
 ####counts 
  
  datareactive <- reactive ({              
    org.counts <- dataInput$dataCount
    metadata <- dataInput$dataMeta
	group <- metadata[,2]
	samples <- metadata[,1]
	
	
	org.count <- DGEList(counts=org.counts, group=group, samples= samples,
						lib.size = colSums(org.counts),
						norm.factors = calcNormFactors(org.counts),)
	Hs_ann <- AnnotationDbi::select(org.Hs.eg.db,
                                keys=rownames(org.count$counts),
                                columns=c("ENTREZID","SYMBOL"),
                                keytype="ENSEMBL",
                                multiVals="first")
  Hs_ann <- Hs_ann[!duplicated(Hs_ann[,1]),]
  org.count$genes <- Hs_ann
    org.count
  })
  
  #### Data summary
  
 output$sampleInfo <- renderTable(
	{
	if (input$upload){
	meta <- myValues()$meta
   	meta
	}})
	  
 output$orgLibsizeNormfactor <- renderTable({
        tab <- datareactive()$samples[,-1]
        #colnames(tab) <- c("Library sizes", "Normalization factors")
        tab
  })
  
  #####Plot unfiltered data
  
  output$boxplotunfiltered <- renderPlot({ 
   Group= datareactive()$samples$group
   unfilteredExpr <- cpm(datareactive(), log=T)
   #myPalette <- c(brewer.pal(8, "Set1"), brewer.pal(8, "Set2"))
   par(mar=c(6,5,2,2))
   boxplot(unfilteredExpr, las=2, col=as.numeric(Group), main="")
   
    
  })
  
  output$plotdensityunfiltered <- renderPlot({ 
  meta <- myValues()$meta
    count <- myValues()$count
   unfilteredExpr <- cpm(datareactive(), log=T)
   myPalette <- c(brewer.pal(8, "Set1"), brewer.pal(8, "Set2"))
   plotDensities(unfilteredExpr, group=factor(meta[,2]), col=myPalette[1:5], main="")
   
    
  })
  
  
  ### Filter by EdgeR
  
  FilterReactive <- reactive({    
    if (input$Filter){
	withProgress(message = 'Filter:', value = 0,{
	incProgress(.1, detail = paste("FIltering data"))
    keep = filterByExpr(datareactive(),min.count = 10, min.total.count = 15)
	filteredcounts <- datareactive()[keep,]
	filteredcounts <- calcNormFactors(filteredcounts)
	filteredcounts
    })
  }})
  
  ####Plot filtered data
  
  output$sampleBoxplot <- renderPlot({ 
  Group = datareactive()$samples$group
  if (input$Filter){
   filteredExpr <- cpm(FilterReactive(), log=T)
   #myPalette <- c(brewer.pal(8, "Set1"), brewer.pal(8, "Set2"))
   par(mar=c(6,5,2,2))
   boxplot(filteredExpr, las=2, col=as.numeric(Group), main="")
   }})
  
  
  output$plotdensities <- renderPlot({ 
  meta <- myValues()$meta
  
  if (input$Filter){
   filteredExpr <- cpm(FilterReactive(), log=T)
   myPalette <- c(brewer.pal(8, "Set1"), brewer.pal(8, "Set2"))
   plotDensities(filteredExpr, group=factor(meta[,2]), col=myPalette[1:5], main="")
   }})
  
  output$mdsplot <- renderPlot({ 
  Group= datareactive()$samples$group
  if (input$Filter){
   filteredExpr <- cpm(FilterReactive(), log=T)
   plotMDS(filteredExpr, labels=Group, col=as.numeric(Group))
  }})
  
  
  ### show the available groups for contrast matrix
  
  output$grouplevels <- renderText({ 
    paste("The available group levels are: " ,
	paste(as.character(levels(datareactive()$samples$group)), collapse=", "), sep="")
  })
 
  ####Making contrast matrix
  
 contrastmatrix <- reactive({      
    if (input$degAnalysis) 
	withProgress(message = 'Submit:', value = 0,{
	incProgress(.1, detail = paste("DEG analysis"))
    Group=datareactive()$samples$group
    f <- factor(Group, levels=levels(Group))
    design <- model.matrix(~0+f)  
    colnames(design) <- levels(Group)
    con2vscon1 = paste(as.character((input$Group2)), as.character((input$Group1)), sep="-")                
                              # levels = colnames(design))
	contr <- makeContrasts(contrasts=con2vscon1, levels = colnames(design))
	contr 
	})
	})
	
	
####Run Voom
	
 voomrun <- reactive ({
  #contrastmatrix()
	v <- voom(FilterReactive(), plot=F)
	#v <- voom(test2(), plot=F)
	v 
})

 ### and plot
output$voomvariance <- renderPlot({
    	isolate({	 
        voom(FilterReactive(), plot=T) 
  })
  })  
 
#### fit the linear model
 
 fitres <-reactive ({
 Group=datareactive()$samples$group
    f <- factor(Group, levels=levels(Group))
    design <- model.matrix(~0+f)  
    #rownames(design) <- rownames(rmlowReactive()$samples)
    colnames(design) <- levels(Group) 
  v1 <- voomrun()
    fit <- lmFit(v1, design)
	fit
	})
	
	
 ### apply your contrasts and ebayes method
 
voomreactive <- eventReactive(input$degAnalysis,{
	Group=datareactive()$samples$group
    f <- factor(Group, levels=levels(Group))
    design <- model.matrix(~0+f)  
    colnames(design) <- levels(Group) 
	cfit <- contrasts.fit(fitres(), contrasts=contrastmatrix())
    efit <- eBayes(cfit)
	(efit)
  }) 
 ###and plot 
 output$voommeanvariance <- renderPlot({
    if (input$degAnalysis){
	      plotSA(voomreactive(), main="Final model: Mean-variance trend")
      }})
 

##### TopTable of DEGs Ebayes method
  
 output$reslimma <- renderDT({
        res_con2vcon1_limma <- topTable(voomreactive(), adjust.method="BH", sort.by = "t", n = Inf)
		res = res_con2vcon1_limma[,c('ENSEMBL', 'ENTREZID',  'SYMBOL', 'logFC','P.Value', 'adj.P.Val','t')]
		res$logFC <- round(res$logFC, digits = 4)
		res$P.Value <- round(res$P.Value)
		res$adj.P.Val <- round(res$adj.P.Val, digits = 5)
		res
	 
  }, filter = 'top',
    rownames = FALSE,
options = list(
  autoWidth = TRUE,
  columnDefs = list(list(width = '100px')))	
  )
  
 #### summary of ebayes degs
 
 output$summarydegs <- renderTable({
  dt1 <- as.data.frame(summary(decideTests(voomreactive())))
  colnames(dt1) <- c('Regulation',"group","Frequency")
  dt1
  })
  
  #### voom download
  output$voomDownload <- downloadHandler(
    filename = function() {
      paste("voom-result", ".csv", sep = "")
    },
    content = function(file) {
      write.csv(as.data.frame(list(voomreactive()$counts, voomreactive()$genes)), file, row.names = FALSE)
    }
  )
  
  
  ##### Treat your degs 
  
  #### reactive treat
  treatvals <- eventReactive(input$treatanalysis,
  
  { 
  withProgress(message = 'Submit:', value = 0,{
	incProgress(.1, detail = paste("treating dataset"))
  tfit <- treat(voomreactive(),lfc=log2(as.numeric(input$FC)))
  })
  })
  
    
  ### datatable of treat method
   output$restreat <- renderDT({
   		tfit2 <-treatvals()
        res_con2vcon1_treat <- topTreat(tfit2,sort.by="t", coef=1, n=Inf)
		res1 = res_con2vcon1_treat[,c('ENSEMBL', 'ENTREZID',  'SYMBOL', 'logFC','P.Value', 'adj.P.Val','t')]
        res1$logFC <- round(res1$logFC, digits = 4)
		res1$P.Value <- round(res1$P.Value)
		res1$adj.P.Val <- round(res1$adj.P.Val, digits = 5)
		res1
	
  
  }, filter = 'top',
    rownames = FALSE 
  )
  
  #### summary of treat analysis
   output$summaryaftertreat <- renderTable({
   tfit2 <-treatvals()
  dt2 <- as.data.frame(summary(decideTests(tfit2)))
  colnames(dt2) <- c('Regulation',"group","Number")
  dt2
  })

#### treat download
output$treatDownload <- downloadHandler(
    filename = function() {
      paste("treat-result", ".csv", sep = "")
    },
    content = function(file) {
    write.csv(as.data.frame(topTreat(treatvals())), file, row.names = FALSE)  
    }
  )


#### MD plot after treat analysis
   output$MDplot <- renderPlot({
   tfit2 <-treatvals()
   dt2 <- (decideTests(tfit2))
   plotMD(object=tfit2, column=1, status=dt2[,1], main=paste(as.character((input$Group2)), as.character((input$Group1)), sep="V"), 
       xlim=c(-8,13))
	   })
  
 
  ##### Run Topconfects
  
  ###reactive topconfects
  confectvals <- eventReactive(input$runconfect,
  { 
  withProgress(message = 'Submit:', value = 0,{
	incProgress(.1, detail = paste("running topconfects"))
  confects_1 <- limma_confects(voomreactive(), fdr=as.numeric(input$fdr))
  })
  })
  
  ### datatable of topconfects
  output$restopconfect <- renderDT({
  
		confect2 <-confectvals()
		confect2$table[, c('rank','ENSEMBL', 'ENTREZID', 'SYMBOL', 'confect','effect','AveExpr')]
         }, filter = 'top',
    rownames = FALSE 
  )
  
 #### summary of topconfects  
  
 ##### MD plot after Topconfects
 
 observeEvent(input$plotlimma_confect,{
  withProgress(message = 'MD plot:', value = 0,{
	 incProgress(.1, detail = paste("ploting"))
	
output$MD_limma_confects <- renderPlot({
isolate({
confect2 <-confectvals()
   top_1 <- topTable(voomreactive(), n=Inf)
   plotMD(fitres() , legend="bottomleft", status=paste0(
   ifelse(rownames(voomreactive()) %in% rownames(top_1)[1:input$n], "topTable ",""),
   ifelse(rownames(voomreactive()) %in% confect2$table$name[1:input$n], "confects ","")))
       })
	   })
	   })
	   }) 


#### Plot the topconfects
output$confectplot <- renderPlot({
 confects_plot(confectvals())
 })
 
##### compare voom and topconfect
 output$voomvsconfectplot <- renderPlot({
top_1 <- topTable(voomreactive(), n=Inf)
rank_rank_plot(confectvals()$table$name, rownames(top_1), "limma_confects", "topTable")
})

######### Enrichment analysis##########

## Camera Competitive Enrichment Analysis ##
#Run Camera geneset enrichment on a comparison
# Select ENTREZID
 
##### pathway reactive entrezid 
 pathwayIDreactive <- reactive({
    switch(input$pathwaysname,
           "Gene_Ontology" = Hs.GOBP.Entrez,
           "Reactome" = Hs.Reactome.Entrez,
           "Hallmark" = Hs.Hallmark.Entrez)
  })
  
 
msigdbgeneset <- reactive({

#Create an object describing the symbol to ensembl identifier conversion
idx <- ids2indices(pathwayIDreactive(),id=voomrun()$genes$ENTREZID)
return(idx)
})

 
#### datatable of CAMERA method
output$enrichmentout <- renderDT ({
if (input$pathwayenrichment)

withProgress(message = '', value = 0,{
	incProgress(.5, detail = paste("Enrichment analysis"))
Group=datareactive()$samples$group
    f <- factor(Group, levels=levels(Group))
    design <- model.matrix(~0+f) 
#Run the camera method from limma, make sure to define the contrast you want to analyze from you contrast matrix - in this case, "1" is Con2vCon1
cam.HsGO.1 <- camera(voomrun(),msigdbgeneset(),design,contrast=contrastmatrix())
# cam.HsGO.1$pval <- round(cam.HsGO.1$pval, digits = 3)
# cam.HsGO.1$padj <- round(cam.HsGO.1$padj, digits = 3)
# cam.HsGO.1$NES <- round(cam.HsGO.1$NES, digits = 3)
cam.HsGO.1
}
)}, filter = 'top'
)
 

 



# output$barcodeout <- renderTable({
# input$barcode
# isolate({
# id=msigdbgeneset()$input$geneset

# id
# # barcodeplot(voomreactive()$t[,1], 

            # # index=id, 
			# # #index2 = msigdbgeneset()$input$geneset2,
            # # main=paste(as.character((input$Group2)), as.character((input$Group1)), sep=" Vs "))
 
     
	  
	   # })
	   # })
	   
	   
	  
####Enrichment analysis using fgsea  

#### reactive element of fgsea

# Run pre-ranked GSEA using fgsea
# Let's use the t value from limma voom results to use as a ranking metric for gsea


### change the genelist to include either ebayes, treat or topconfects
genelistreactive <- reactive({
    switch(input$genelist,
           "ebayes_genelist" = topTable(voomreactive(), adjust.method="BH", sort.by = "t", n = Inf),
           "treat_genelist" = topTreat(treatvals(),sort.by="t", coef=1, n=Inf),
           "topconfects_genelist" = confectvals()$table)
  })
	 
 
fgseaoutreactive <- eventReactive(input$topgenes,
    { 
    res_con2vcon1 <- genelistreactive()
	if (input$genelist == "ebayes_genelist" | input$genelist == "treat_genelist"){
		#res = res_con2vcon1[,c('ENSEMBL', 'ENTREZID', 't', 'SYMBOL', 'logFC','P.Value', 'adj.P.Val')]
		res_con2vcon1$logFC <- round(res_con2vcon1$logFC, digits = 4)
		res_con2vcon1$P.Value <- round(res_con2vcon1$P.Value)
		res_con2vcon1$adj.P.Val <- round(res_con2vcon1$adj.P.Val, digits = 5)
		res_con2vcon1 <- subset(res_con2vcon1, SYMBOL != "" )
	res_con2vcon1 <- subset(res_con2vcon1, !duplicated(SYMBOL))
ranks_limma <- res_con2vcon1[order(res_con2vcon1$t), ]
ranks_limma1 <- ranks_limma[, c('SYMBOL','t')]
return(ranks_limma1)
}

if (input$genelist == "topconfects_genelist")
{
res_confects <- subset(res_confects, SYMBOL != "" )
res_confects <- subset(res_confects, !duplicated(SYMBOL))
# coerce confects with a NA score to 0
res_confects[is.na(res_confects)] <- 0
ranks_limma2 <- res_confects[order(res_confects$confect), ]
ranks_limma3 <- ranks_limma2[, c('SYMBOL','confect')]
return(ranks_limma3)
}

  })
 
### output of fgsea   
 output$fgseaout <- renderTable ({

withProgress(message = '', value = 0,{
	incProgress(.5, detail = paste("Top genes"))
 
 head(fgseaoutreactive(), n=input$ngenes)
  })
  })
  
 #### change pathways
 pathwayreactive <- reactive({
    switch(input$pathwaylist,
           "Gene_Ontology" = Hs.GOBP.Symbol,
           "Reactome" = Hs.Reactome.Symbol,
           "Hallmark" = Hs.Hallmark.Symbol)
  })
  
  #### see the top n genes by t 
 output$fgseaout_gobp <- renderDT ({
 withProgress(message = '', value = 0,{
	incProgress(.5, detail = paste("Top genes"))
 ranks <- deframe(fgseaoutreactive())
 # Run fGSEA 
  fgseaRes <- fgseaMultilevel(pathways=pathwayreactive(), stats=ranks, minSize = 15, maxSize = 500)
# Make the Results tidy
fgseaResTidy <- fgseaRes %>%
  as_tibble() %>%
  dplyr::select(-leadingEdge, -ES) %>% 
  arrange(desc(NES))
head(fgseaResTidy,input$ngenes)
	})},filter = 'top',
    rownames = FALSE)


##### Enrichr ########

genesreactive <- reactive({
    switch(input$genes,
           "ebayes_genelist" = topTable(voomreactive(), adjust.method="BH", sort.by = "t", n = Inf),
           "treat_genelist" = topTreat(treatvals(),sort.by="t", coef=1, n=Inf)
           )
  })

enrichrreactive <- eventReactive(input$runenrichr,{
res_limma <- genesreactive()
res_limma_down <- res_limma[which(res_limma$logFC < 0.5), ]	
down_genes <- as.character(res_limma_down$SYMBOL)
down_enriched <- enrichr(c(down_genes), input$database)

res_limma_up <- res_limma[which(res_limma$logFC > 0.5), ]
up_genes <- as.character(res_limma_up$SYMBOL)
up_enriched <- enrichr(c(up_genes), input$database)

list(down_enriched1 = down_enriched, up_enriched1 =up_enriched)
})


output$down_enrichr <- renderDT({
withProgress(message = '', value = 0,{
	incProgress(.5, detail = paste("running enrichr"))
	

# Select a single database enichment
down_enriched_ECC <- enrichrreactive()$down_enriched1[[input$database]]  
down_enriched_ECC_Tidy <- down_enriched_ECC %>%
  as_tibble() %>%
  arrange(desc(Combined.Score))
# Show in a nice table - Sort by Combined.Score
# down_enriched_ECC_Tidy %>% 
  # dplyr::select(-P.value, -Old.P.value, -Old.Adjusted.P.value) %>% 
  # arrange(desc(Combined.Score))
  })}, filter = 'top',
    rownames = FALSE)
  
  
  output$up_enrichr <- renderDT({
  withProgress(message = '', value = 0,{
	incProgress(.5, detail = paste("running enrichr"))
#Define your up- and down-regulated genes

up_enriched_ECC <- enrichrreactive()$up_enriched1[[input$database]]  
up_enriched_ECC_Tidy <- up_enriched_ECC %>%
  as_tibble() %>%
  arrange(desc(Combined.Score))
# Show in a nice table - Sort by Combined.Score
# up_enriched_ECC_Tidy %>% 
  # dplyr::select(-P.value, -Old.P.value, -Old.Adjusted.P.value) %>% 
  # arrange(desc(Combined.Score))
  })}, filter = 'top',
    rownames = FALSE)
  
 ######DoRothEA#####
  
  genesreactivedorothea <- reactive({
    switch(input$genesl,
           "ebayes_genelist" = topTable(voomreactive(), adjust.method="BH", sort.by = "t", n = Inf),
           "treat_genelist" = topTreat(treatvals(),sort.by="t", coef=1, n=Inf)
           )
  })
  
  
  output$dorothea <-renderDT({
  withProgress(message = '', value = 0,{
	incProgress(.5, detail = paste("running dorothea"))
  DEsignature <- topTable(voomreactive(), coef=1, adjust.method="BH", sort.by = "t", n = Inf)
# Exclude probes with unknown or duplicated gene symbol
DEsignature <- subset(DEsignature, SYMBOL != "" )
DEsignature <- subset(DEsignature, ! duplicated(SYMBOL))
# Estimate z-score values for the GES. Check VIPER manual for details
myStatistics <- matrix(DEsignature$logFC, dimnames = list(DEsignature$SYMBOL, 'logFC') )
myPvalue <- matrix(DEsignature$P.Value, dimnames = list(DEsignature$SYMBOL, 'P.Value') )
mySignature <- (qnorm(myPvalue/2, lower.tail = FALSE) * sign(myStatistics))[, 1]
# Reorder
mySignature <- mySignature[order(mySignature, decreasing = T)]
mrs <- msviper(ges = mySignature, regulon = viper_regulon, minsize = 4, ges.filter = F, verbose = TRUE) 
  TF_activities <- data.frame(Regulon = names(mrs$es$nes),
                            Size = mrs$es$size[ names(mrs$es$nes) ], 
                            NES = mrs$es$nes, 
                            p.value = mrs$es$p.value, 
                            FDR = p.adjust(mrs$es$p.value, method = 'fdr'))
TF_activitiesTidy <- TF_activities %>%
  as_tibble() %>%
  arrange(FDR)	
TF_activitiesTidy  
							})}, filter = 'top',
    rownames = FALSE)
	
### dorothea summary	
output$genesummary <- renderTable({

  DEsignature <- topTable(voomreactive(), coef=1, adjust.method="BH", sort.by = "t", n = Inf)
# Exclude probes with unknown or duplicated gene symbol
DEsignature <- subset(DEsignature, SYMBOL != "" )
DEsignature <- subset(DEsignature, ! duplicated(SYMBOL))
# Estimate z-score values for the GES. Check VIPER manual for details
myStatistics <- matrix(DEsignature$logFC, dimnames = list(DEsignature$SYMBOL, 'logFC') )
myPvalue <- matrix(DEsignature$P.Value, dimnames = list(DEsignature$SYMBOL, 'P.Value') )
mySignature <- (qnorm(myPvalue/2, lower.tail = FALSE) * sign(myStatistics))[, 1]
# Reorder
mySignature <- mySignature[order(mySignature, decreasing = T)]
mrs <- msviper(ges = mySignature, regulon = viper_regulon, minsize = 4, ges.filter = F, verbose = TRUE) 
mrs <- ledge(mrs)
# See the results
summary(mrs)
})


#####Next steps

output$Next_step <- renderUI({
    if(input$upload)
    actionButton('Next', label = "Next step: Data Summary", class = "btn-primary")
     
  })
  
  output$Next_step2 <- renderUI({
    if(input$Filter)
    actionButton('Next2', label = "Next step: Choose groups", class = "btn-primary")
     
  })
  
  output$Next_step3 <- renderUI({
    if(input$Filter)
    actionButton('Next3', label = "Next step: Differential gene expression", class = "btn-primary")
     
  })
  
  
  
  output$Next_step4 <- renderUI({
    #if(input$Filter)
	isolate({
    list(
	actionButton('prev', label = "Previous step: Change groups", class = "btn-primary"),
	actionButton('Next4', label = "Next steps: a) Treat analysis of DEGs", class = "btn-primary"),
	actionButton('Next5', label = "b) Run Topconfects", class = "btn-primary"),
	actionButton('Next6', label = "Enrichment analysis (Camera)", class = "btn-primary"),
	actionButton('Next10', label = "Enrichment analysis (GSEA)", class = "btn-primary")
     )
  })
  })

  
   output$Next_step7 <- renderUI({
    #if(input$Filter)
	isolate({
    list(
    
	actionButton('Next8', label = "Run topconfects", class = "btn-primary"),
	actionButton('Next7', label = "Go to Enrichment analysis (Camera)", class = "btn-primary"),
	actionButton('Nextgsea1', label = "Go to Enrichment analysis (GSEA)", class = "btn-primary")
      )
  })
  })
  
  
   output$Next_step8 <- renderUI({
    #if(input$Filter)
    actionButton('Next8', label = "Run topconfects", class = "btn-primary")
     
  })
  
  output$Next_step9 <- renderUI({
    #if(input$Filter)
	isolate({
    list(
    actionButton('Next9', label = "Go to Enrichment analysis (Camera)", class = "btn-primary"),
	actionButton('Next13', label = "Go to Enrichment analysis (GSEA)", class = "btn-primary")
    )
  })  
     
  })
  
  output$Next_step10 <- renderUI({
    #if(input$Filter)
    actionButton('Nextgsea2', label = "Go to Enrichment analysis (GSEA)", class = "btn-primary")
    
  })
  
   output$Next_step11 <- renderUI({
    #if(input$Filter)
    actionButton('Next11', label = "Go to Enrichment analysis (GSEA)", class = "btn-primary")
     
  })
  
  output$Next_step12 <- renderUI({
    #if(input$Filter)
	isolate({
    list(
    actionButton('Next12', label = "Go to TF Enrichment analysis (Enrichr)", class = "btn-primary"),
	actionButton('Nexttf', label = "Go to TF Enrichment analysis (DoRothEA)", class = "btn-primary")
	
    )
  })  
  })
  
  output$Next_stepdorothEA <- renderUI({
    #if(input$Filter)
    actionButton('stepdorothEA', label = "Go to TF Enrichment analysis (DoRothEA)", class = "btn-primary")
     
  })
  
  observeEvent(input$Next, {
    tab1 <- switch(input$sidebarmenu,"dataSummary")
    updateTabItems(session, "sidebarmenu", tab1)
  })
  
  observeEvent(input$Next2, {
    tab2 <- switch(input$sidebarmenu,"limmavoom")
    updateTabItems(session, "sidebarmenu", tab2)
  })
  
  observeEvent(input$Next3, {
    tab3 <- switch(input$sidebarmenu,"DEGs")
    updateTabItems(session, "sidebarmenu", tab3)
  })
  
   observeEvent(input$Next4, {
    tab4 <- switch(input$sidebarmenu,"treatmethod")
    updateTabItems(session, "sidebarmenu", tab4)
  })
  
  observeEvent(input$prev, {
    tab5 <- switch(input$sidebarmenu,"limmavoom")
    updateTabItems(session, "sidebarmenu", tab5)
  })
  observeEvent(input$Next5, {
    tab6 <- switch(input$sidebarmenu,"confect")
    updateTabItems(session, "sidebarmenu", tab6)
  })
  
  observeEvent(input$Next6, {
    tab7 <- switch(input$sidebarmenu,"camera")
    updateTabItems(session, "sidebarmenu", tab7)
  })
  
  observeEvent(input$Next7, {
    tab8 <- switch(input$sidebarmenu,"camera")
    updateTabItems(session, "sidebarmenu", tab8)
  })
  
  observeEvent(input$Next8, {
    tab9 <- switch(input$sidebarmenu,"confect")
    updateTabItems(session, "sidebarmenu", tab9)
  })
  
  observeEvent(input$Next9, {
    tab10 <- switch(input$sidebarmenu,"camera")
    updateTabItems(session, "sidebarmenu", tab10)
  })
  
  observeEvent(input$Next10, {
    tab11 <- switch(input$sidebarmenu,"fgsea")
    updateTabItems(session, "sidebarmenu", tab11)
  })
  
  observeEvent(input$Next11, {
    tab12 <- switch(input$sidebarmenu,"fgsea")
    updateTabItems(session, "sidebarmenu", tab12)
  })
  
  observeEvent(input$Next12, {
    tab13 <- switch(input$sidebarmenu,"enrichr")
    updateTabItems(session, "sidebarmenu", tab13)
  })
  
  observeEvent(input$Next13, {
    tab14 <- switch(input$sidebarmenu,"fgsea")
    updateTabItems(session, "sidebarmenu", tab14)
  })
  
  observeEvent(input$Nexttf, {
    tab15 <- switch(input$sidebarmenu,"dorothEA")
    updateTabItems(session, "sidebarmenu", tab15)
  })
  

observeEvent(input$stepdorothEA, {
    tab16 <- switch(input$sidebarmenu,"dorothEA")
    updateTabItems(session, "sidebarmenu", tab16)
  }) 
  
  
  observeEvent(input$Nextgsea1, {
    tab17 <- switch(input$sidebarmenu,"fgsea")
    updateTabItems(session, "sidebarmenu", tab17)
  })
  
  observeEvent(input$Nextgsea2, {
    tab18 <- switch(input$sidebarmenu,"fgsea")
    updateTabItems(session, "sidebarmenu", tab18)
  })
  

  
  }
  