

source(paste(getwd(),'global.R',sep="/"))

header <- dashboardHeader(
  title = "Gene Expression ShinyApp",
  titleWidth = 250
)
#sidebar <- dashboardSidebar()
sidebar <- dashboardSidebar( 
		sidebarMenu(id = "sidebarmenu",
 
              menuItem("Data Upload", tabName = "dataInputCounts", icon = icon("dashboard")),
                       
                       
              menuItem("Data Summary", tabName="dataSummary", icon = icon("th")),
			  
              menuItem("Mean-variance trend", tabName="limmavoom", icon = icon("dashboard")),
			  menuItem("Differential gene analysis", icon = icon("dashboard"),
						menuSubItem("Ebayes", tabName="DEGs"),
                       menuSubItem("Treat method", tabName="treatmethod"),
                       menuSubItem("Topconfect", tabName="confect")
			  ),
			  menuItem("Enrichment Analysis", tabName="enrichment", icon = icon("chart-bar"),
			  menuSubItem("Camera Method", tabName="camera"),
                       menuSubItem("GSEA competitive enrichment test", tabName="fgsea")
                      # menuSubItem("Topconfect", tabName="confect")
			  
			  ),
			  menuItem("TF Enrichment Analysis", tabName="TFenrichment", icon = icon("chart-bar"),
			  menuSubItem("Enrichr", tabName="enrichr"),
              menuSubItem("DoRothEA", tabName="dorothEA"))
                       
              
  ))
         


body <- dashboardBody(

	tags$head( 
    tags$link(rel = "stylesheet", type = "text/css", href = "my_style.css"),
	 tags$script(
        HTML("
  $(document).ready(function(){
    resize();
  })
  function resize(){
    var h = window.innerHeight - $('.navbar').height() - 150; // Get dashboardBody height
    $('#box').height(h); 
  }"
    )
      )
   ),
   tags$h4( 
    tags$link(rel = "stylesheet", type = "text/css", href = "my_style.css"),
	    ),
  tabItems(
   tabItem(tabName="dataInputCounts",
			fluidRow(
			
              box(title = "Upload Data",
                   solidHeader = T, status = "primary",
                   width = 6,
                        helpText("Upload your 'Raw Count Data' here. Format your dataset as comma seperated value files (.csv), with the first column 
						giving the gene info and the other columns for raw count reads for each sample. 
						If you do not have raw data, please hit submit button and example data (GSE76987: left_colon_processed) will be loaded"
                                 ,style="color:black; padding-right:0em; font-size:12px;"),
                       # popify(placement = "bottom", title = "File-input info",
                        fileInput("countFile","Choose CSV File", 
                                  accept=c( "text/csv",
											"text/comma-separated-values,text/plain",
											".csv")),
						# content = 'Upload your Raw Count Data here. Format your dataset as comma seperated value files (.csv), with the first column giving the gene info and 
						# the other columns for raw count reads for each sample. 
						# If you do not have raw data, please hit submit button and example data will be loaded.'
                                                                      
                        # ),
                                                              
                        helpText("Upload your 'Meta-data Table' here. Format the metadata as tab-delimited file with sample name in one column and conditions in the other.
						If you do not have meta data, please hit submit button and example data will be loaded"
                                 ,style="color:black; padding-right:0em;font-size:12px;"),
                        
                        fileInput("metaTab", 
                                  "Choose tab-delimited file",
                                  accept = c('text/tab-separated-values',                                             
                                             'text/tab-separated-values',
                                             '.txt',                                             
                                             '.tsv')
                        ),
                  actionButton("upload", label = "Submit",icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4")
	),
                  #tags$style("button#upload {margin-left:auto;margin-right:auto;display:block; background-color:#00CCFF; padding: 5px 25px; font-family:Andika, Arial, sans-serif; font-size:1.5em;  letter-spacing:0.05em; text-transform:uppercase ;color:#fff; text-shadow: 0px 1px 10px #000;border-radius: 15px;box-shadow: rgba(0, 0, 0, .55) 0 1px 6px;}"),
                  # ),       
            
            ##Input information summary under Data Input Panel
            
              box(title = "Input data Summary",
                  solidHeader = T, status = "primary",
                  
                  width = 6, 
                  
                   
					h4("samples in the datasets"),
                           tableOutput("sampleInfo")
                    
                    # column(6,
                    # h4("Groups in the sample"),       
                           # verbatimTextOutput("GroupLevel")
                    # ),
					
					# column (8,
					# h4("Overall view"),
					# tableOutput("view"))
                  ),
				  uiOutput("Next_step", align = "center")
				# fluidRow(
              # box(title = "Raw Counts",
                   # solidHeader = T, status = "primary",
                   # tableOutput("view")
				   
				  # ))
				  )),
   
    #########################################
    ## Second tab content for data summarization panel
    tabItem(tabName="dataSummary",
            
            ##First 3 box under Data Summarization panel
            fluidRow(
              box(title = "Data summary without filtering",
                  solidHeader = T, status = "primary",  width=12,                               
                  
                  fluidRow(
                    ##Raw Count Summary box under the Data Summarization panel
                    
					box(title = "Raw Count Summary",
                       
                        status = "primary",
                        width = 4,
                        #fluidRow(
                        #  column(4,
                                 div(tableOutput("orgLibsizeNormfactor"),style = "font-size:70%"),
                                 tags$style("#orgLibsizeNormfactor table {border: 1px solid black; float: center; position:relative;}","#orgLibsizeNormfactor th {border: 1px solid black;}","#orgLibsizeNormfactor td {border: 1px solid black;}")
                          ),
						  box(title = "Density Plot of unfiltered gene expression",
                        
                        status = "primary",
                        width = 4,
                        
                          #column(4,
						  plotOutput("plotdensityunfiltered")
                                 ),
								 box(title = "Box Plot of unfiltered gene expression",
                        
                        status = "primary",
                        width = 4,
                         
						  plotOutput("boxplotunfiltered")
						  )))),
		  
				  actionButton("Filter", label = "Filter via EdgeR", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4"),
                  helpText(textOutput("errorFiltering"), style="color:red;"),
   
    
    fluidRow(
      box(title = "After filtering via EdgeR",
                  solidHeader = T, status = "primary",  width=12, 
      ## Sample Normalization box plot under Data Summarization panel
	  fluidRow(
	  
	  box(title = "Plot densities after filteration",
          status = "primary",
          width = 4,
          plotOutput("plotdensities")
      ),
      box(title = "Boxplot after filteration",
          status = "primary",
          width = 4,
          plotOutput("sampleBoxplot")
		  ),
	box(title = "MDS plot",
           status = "primary",
          width = 4,
          plotOutput("mdsplot")
		  )	  
		  ))),
			uiOutput("Next_step2", align = "center")
		  
		  ),
		  
   
    
    tabItem(tabName="limmavoom",            
            ## 1st row with 2 boxes under limma-voom tab panel
            fluidRow(
              box(title = "Contrast matrix and Mean-variance trend",
                  solidHeader = T, status = "primary",                  
                  width = 12,
                  fluidRow(
                       column(6,              
                     ## Estimated dispersion under limma-voom tab panel
                     box(title = "Mean-variance trend",
                         width = NULL,
                         status = "primary",
                         plotOutput("voomvariance")
                     )),
                                 
                    ## DE filtering criteria option box under limma-voom tab panel
                    # box(title = "DEG Analysis Filtering options",
                        # width = 4,
                        # solidHeader = T,
                        # status = "primary",
                        # fluidRow(
                        
                          # column(4,
                                 # textInput(inputId="voomfdr", 
                                           # label="p-value or FDR adjusted p-value", 
                                           # value="0.05")
                          # ),
                          # column(4,
                                 # textInput(inputId="voomfc", 
                                           # label="Fold Change (FC)", 
                                           # value="1.5")
                          # )
                        # )
                        
                    # ),
                    column(6,
              box(title = "Create the group for contrast matrix and DEGs",
                        
                        status = "primary",
                        textOutput("grouplevels"),
                        #tags$style("#voomGroupLevel{ font-weight: bold; color: #0033FF; padding-top: .3cm; padding-bottom: .3cm;}"),
                        p("Please select any two groups for comparison, one set is already selected for example"
                          , style="font-weight: bold"),
                        
                        fluidRow(
                          column(6,
                                 textInput(inputId="Group1", 
                                           label="Group 1" 
                                           )
                          ),
                          column(6,
                                 textInput(inputId="Group2", 
                                           label="Group 2" 
                                           )
                          ),
						 actionButton(inputId="degAnalysis", label="Submit", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4") 
                        )
						
                    )
					
					) 
                    #tags$style("button#voomdeAnalysis {margin-top:0.5em;float:right; margin-right: 1em; background-color:#00CCFF; padding: 5px 25px; font-family:Andika, Arial, sans-serif; font-size:1.5em;  letter-spacing:0.05em; text-transform:uppercase ;color:#fff; text-shadow: 0px 1px 10px #000;border-radius: 15px;box-shadow: rgba(0, 0, 0, .55) 0 1px 6px;}")
                  ),
                  helpText(textOutput("errorVoom"), style="color:red;")

              )
            ),
            
            
            fluidRow(
   					column(6,
                     box(title = "Plot of fitted microarray linear model",
                         width = NULL,
                         status = "primary",
                         plotOutput("voommeanvariance")
                     )
					)
                     
                     
              )
			  ,
			uiOutput("Next_step3", align = "center")
			  
            ),   
          

	tabItem(tabName="DEGs",            
            ## 1st row with 2 boxes under limma-voom tab panel
            # fluidRow(
              # box(title = "Differential gene expression between groups",
                  # solidHeader = T, status = "primary",                  
                  # width = 12,
                  fluidRow(
                       #column(8,              
                     ## Estimated dispersion under limma-voom tab panel
                     box(title = "Toptable of Differentially expressed genes (ebayes method)",
                         width = NULL,
                         solidHeader = T, status = "primary",
                         div(DTOutput("reslimma"),style = "font-size:70%"),
						 downloadButton("voomDownload", 
                                        label = "Download",
                                        class = NULL)
                     
					 
					 
					 
                     ),
					 
					 #column(4,
                     
                     ## DEGs Summary to summarize the up- and down-regulated DEGs
                     box(title = "DEGs Summary",
                         width = NULL,
                         
                         solidHeader = T, status = "primary",
                        # h4(textOutput("voomTestDGEtitle"), align="center" ),
                         tableOutput("summarydegs"),
                         #tags$style("#voomTestDGE table {border: 1px solid black; align: center; margin:auto;}","#voomTestDGE th {border: 1px solid black;}","#voomTestDGE td {border: 1px solid black;}"),
                         
                         # downloadButton("voomDownload", 
                                        # label = "Download",
                                        # class = NULL),
                         #tags$style("#voomDownload {float:right; }")
                         #helpText("Download DEGs results")
                     ),
                     ),
					 #uiOutput("prev_step"),
			#uiOutput("Next_step10", align="right"),		 
			uiOutput("Next_step4", align="center")
			#br(),
			#uiOutput("Next_step5", align="center"),
			#br(),
			#uiOutput("Next_step6", align="center")
			
			)	,

tabItem(tabName="treatmethod",            
            ## 1st row with 2 boxes under limma-voom tab panel
            fluidRow(
              box(title = "Treat analysis for significant DEGs",
                  solidHeader = T, status = "primary",                  
                  width = 12,
				  
					 
					 box(title = "Toptable of Differentially expressed genes (treat method)",
                         width = NULL,
                         status = "primary",
                         div(DTOutput("restreat"), style = "font-size:70%"),
						 downloadButton("treatDownload", 
                                        label = "Download",
                                        class = NULL)
                     ),
					 column(6,
					  box(title = "Treat analysis",
                         width = NULL,
                         status = "primary",
						 h4("Treat analysis ranks the genes according to FDR p-value AND logFC"),
						 textInput(inputId="FC", 
                                           label="Fold Change", 
                                           value="1.5"),
						actionButton(inputId="treatanalysis", label="Treat", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4"),
						 tableOutput("summaryaftertreat"),
                         
                     )),
					 column(6,
					 box(title = "MD plot after Treat analysis",
                         width = NULL,
                         status = "primary",
						 #tableOutput("summaryaftertreat"),
                         plotOutput("MDplot")
                     ))
					 ))
					 ,uiOutput("Next_step7", center = "align")
					 ),

						 
	tabItem(tabName="confect",            
            # # 1st row with 2 boxes under limma-voom tab panel
            fluidRow(
              box(title = "Run topconfects for significant DEGs",
                  solidHeader = T, status = "primary",                  
                  width = 12,
				box(title = "Toptable of Differentially expressed genes (topconfect method)",
                         width = NULL,
                         status = "primary",
						 h4("Topconfects builds on TREAT p-values offered by the limma and edgeR packages"),
						 textInput(inputId="fdr", 
                                           label="FDR", 
                                           value="0.05"),
						actionButton(inputId="runconfect", label="Run topconfects", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4"),
                         div(DTOutput("restopconfect"), style = "font-size:70%")				  
))),
				fluidRow(
				column(4,
					 box(title = "Plot topconfects result",
                         width = NULL,
                         status = "primary",
						 #tableOutput("summaryaftertreat"),
                         plotOutput("confectplot")
                     )),
					  column(4,
					 box(title = "Compare between top limma voom DEGs and confects DEGs",
                         width = NULL,
                         status = "primary",
						 #tableOutput("summaryaftertreat"),
                         plotOutput("voomvsconfectplot")
                     )),
					 column(4,
					 box(title = "MD plot of the top n number of genes ranked by limma efit or confects",
                         width = NULL,
                         status = "primary",
						 #tableOutput("summaryaftertreat"),
						 textInput(inputId="n", 
                                           label="No. of genes", 
                                           value="500"),
						actionButton(inputId="plotlimma_confect", label="MD plot", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4"),
                         plotOutput("MD_limma_confects")
                     ))
)
,uiOutput("Next_step9", align = "center")

),

tabItem(tabName="camera",
	fluidRow(
                                     
      
                     box(title = "Enrichment analysis through Camera Method for ebayes genelist",
                         width = NULL,
                         solidHeader = T, status = "primary",
						 helpText('Choose Pathways',style="color:black; padding-right:0em; font-size:12px;"),
						selectInput(inputId = "pathwaysname",
					label = "Choose Pathway:",
					choices = c("Gene_Ontology", 
							"Reactome", 
							"Hallmark")),
							actionButton(inputId="pathwayenrichment", label="Enrichment (CAMERA)", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4"),
                         div(DTOutput("enrichmentout"), style = "font-size:70%")
                     )
					 # box(title = "Barcode plot",
                         
                         # solidHeader = T, status = "primary",
						 # h4("Enter Gene-sets you want to compare, you may choose to select just one"),
						 # textInput(inputId="geneset", 
                                           # label="Gene Set",
											# value= "GO_DNA_DEPENDENT_DNA_REPLICATION"
                                    # ),
						
						# actionButton(inputId="barcode", label="Barcode Plot"),										   
						
                         # tableOutput("barcodeout")
                     # )
					 
					 )
					,uiOutput("Next_step11", align="center") 
					 ),				  
					 
tabItem(tabName="fgsea",
	fluidRow(
               box(title = "GSEA competitive enrichment test with fgsea",
                         width = NULL,
                         solidHeader = T, status = "primary",  
					 box(title = "Biological Processes of top n upregulated genesets",
                         width = NULL,
                         solidHeader = T, status = "primary",
						 helpText("Check the enrichment of top n number of genes you select below", style="color:black; padding-right:0em; font-size:12px;"),
                         div(DTOutput("fgseaout_gobp"), style = "font-size:70%")
                     ),
					 column(4,
					  box(title = "Filter criteria",
                         width = NULL,
                         solidHeader = T, status = "primary",
						 helpText('Indicate the number of top genes', style="color:black; padding-right:0em; font-size:12px;"),
						 numericInput(inputId="ngenes", 
                                           label="No. of genes", 
                                           value="10"),
						helpText('Choose from the Genelist, be careful to run Treat and/or Topconfects if you choose either of these',style="color:black; padding-right:0em; font-size:12px;"),
						selectInput(inputId = "genelist",
                  label = "Choose a gene list:",
                  choices = c("ebayes_genelist", 
							"treat_genelist", 
							"topconfects_genelist")),
							
					helpText('Camera competitive enrichment test on Ebayes result',style="color:black; padding-right:0em; font-size:12px;"),
						selectInput(inputId = "pathwaylist",
                  label = "Choose Pathway:",
                  choices = c("Gene_Ontology", 
							"Reactome", 
							"Hallmark")),		
						actionButton(inputId="topgenes", label="Top Genes", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4"),
	                     )),
					  column(4,
					  box(title = "View the top n genes",
                         width = NULL,
                         solidHeader = T, status = "primary",
						 
                         tableOutput("fgseaout")
                     ))
					 
					 
					 ))
					 ,uiOutput("Next_step12", align="center") 
					 ),

	tabItem(tabName="enrichr",
	fluidRow(
                    			 
					 box(title = "TF enrichment on up-regulated genes",
                         width = NULL,
                         solidHeader = T, status = "primary",
                         div(DTOutput("up_enrichr"), style = "font-size:70%")
                     ),
					
					  box(title = "TF Enrichment analysis on down-regulated genes",
                         width = NULL,
                         solidHeader = T, status = "primary",
						 						
						div(DTOutput("down_enrichr"), style = "font-size:70%")
                     ,
			helpText('Choose from the Genelist, be careful to run Treat if you choose that option',style="color:black; padding-right:0em; font-size:12px;"),
						selectInput(inputId = "genes",
                  label = "Choose a gene list:",
                  choices = c("ebayes_genelist", 
							"treat_genelist")),		 
			selectInput(inputId = "database",
                  label = "Choose a enrichment database:",
                  choices = c("TRANSFAC_and_JASPAR_PWMs", 
							"ENCODE_TF_ChIP-seq_2015", 
							"ChEA_2016",
							"ARCHS4_TFs_Coexp",
							"ENCODE_and_ChEA_Consensus_TFs_from_ChIP-X"))		 
					 ,		
						actionButton(inputId="runenrichr", label="Run enrichr", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4"))
	)
	                    
					,uiOutput("Next_stepdorothEA", align="center")  
					 ),

	tabItem(tabName="dorothEA",
	fluidRow(
                  box(title = "TF Activity Analysis on Ebayes gene list",
                         width = NULL,
                         solidHeader = T, status = "primary",
					 box(title = "DoRothEA TF Activity Analysis",
                         width = NULL,
                         solidHeader = T, status = "primary",
                         div(DTOutput("dorothea"), style = "font-size:70%")
                     ),
					
					  box(title = "Genes contributing most to these TF activity",
                         width = NULL,
                         solidHeader = T, status = "primary",
						 					
                         tableOutput("genesummary")
						 ),
			helpText('Choose from the Genelist, be careful to run Treat if you choose that option',style="color:black; padding-right:0em; font-size:12px;"),
						selectInput(inputId = "genesl",
                  label = "Choose a gene list:",
                  choices = c("ebayes_genelist", 
							"treat_genelist"))
                     
					,		
						actionButton(inputId="rundorothea", label="Run DoRothEA", icon("paper-plane"), 
    style="color: #fff; background-color: #337ab7; border-color: #2e6da4") 
				 
					 )))				 
	
            
    )
    )
	
	ui <- dashboardPage(header, sidebar, body)
	
  























